{
	"name" : "Marketing Campaigns",
	"version" : "1.0",
	"author" : "Tiny",
	"website" : "http://tinyerp.com/module_crm_marketing.html",
	"category" : "Generic Modules/Others",
	"depends" : ["base"],
	"description": "Marketing management module",
	"init_xml" : [],
	"demo_xml" : ["campaign/campaign_demo.xml"],
	"update_xml" : ["campaign/campaign_view.xml", "campaign/campaign_wizard.xml"],
	"active": False,
	"installable": True
}
